Class: NPR::Parent
Overview
Parent represents the parent topics to which a story belongs. Parents have:
- id - a unique NPR ID for the Parent
- title - the title of the parent topic
- link - a hash containing the API URI for a parent and the normal web URI
- type - usually a topic, series, or column
Instance Attribute Summary collapse
-
#id ⇒ Object
Returns the value of attribute id.
-
#link ⇒ Object
Returns the value of attribute link.
-
#title ⇒ Object
Returns the value of attribute title.
-
#type ⇒ Object
Returns the value of attribute type.
Method Summary
Methods inherited from Content
Constructor Details
This class inherits a constructor from NPR::Content
Instance Attribute Details
#id ⇒ Object
Returns the value of attribute id.
11 12 13 |
# File 'lib/rubynpr/parent.rb', line 11 def id @id end |
#link ⇒ Object
Returns the value of attribute link.
11 12 13 |
# File 'lib/rubynpr/parent.rb', line 11 def link @link end |
#title ⇒ Object
Returns the value of attribute title.
11 12 13 |
# File 'lib/rubynpr/parent.rb', line 11 def title @title end |
#type ⇒ Object
Returns the value of attribute type.
11 12 13 |
# File 'lib/rubynpr/parent.rb', line 11 def type @type end |